Struct TransactionDenyRules
pub struct TransactionDenyRules {
pub id: UID,
pub inner: Versioned,
}Expand description
Rust version of the Move
iota::transaction_deny_rules::TransactionDenyRules type.
Singleton shared object storing the active transaction deny rules. The actual state lives in a versioned inner field.
Fields
id: UIDinner: VersionedTrait Implementations
impl Clone for TransactionDenyRules
impl Clone for TransactionDenyRules
fn clone(&self) -> TransactionDenyRules
fn clone(&self) -> TransactionDenyRules
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for TransactionDenyRules
impl Debug for TransactionDenyRules
impl<'de> Deserialize<'de> for TransactionDenyRules
impl<'de> Deserialize<'de> for TransactionDenyRules
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TransactionDenyRules, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<TransactionDenyRules, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TransactionDenyRules
impl PartialEq for TransactionDenyRules
impl PartialEq for TransactionDenyRules
fn eq(&self, other: &TransactionDenyRules) -> bool
fn eq(&self, other: &TransactionDenyRules) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Serialize for TransactionDenyRules
impl Serialize for TransactionDenyRules
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for TransactionDenyRules
impl TryFrom<&Object> for TransactionDenyRules
Available on crate feature serde only.Decode a TransactionDenyRules from an on-chain object, validating that the object’s Move type tag matches.
impl TryFrom<&Object> for TransactionDenyRules
Available on crate feature
serde only.Decode a TransactionDenyRules from an on-chain object, validating that the object’s Move type tag matches.